This is a **cron widget** for for `YAFOWIL
<http://pypi.python.org/pypi/yafowil>`_

This widget produces crontab rules.

They can then be used with:
    https://github.com/josiahcarlson/parse-crontab
    https://pypi.python.org/pypi/crontab

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#cron>`_
- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.cron/index.html>`_


Contributors
============

- Johannes Raggam

- Robert Niederrreiter

- Georg Bernhard

